@@ -1,11 +1,11 @@
-from astropy.units import Quantity
+from astropy.units import Quantity, Unit
 
 from cosmoglobe.sky._base_components import DiffuseComponent
-from cosmoglobe.sky.components import SkyComponentLabel
+from cosmoglobe.sky.components._labels import SkyComponentLabel
 
 
 class CMB(DiffuseComponent):
-    r"""Class representing the CMB component.
+    r"""Class representing the CMB component in the Cosmoglobe Sky Model.
 
     Notes
     -----
@@ -25,12 +25,13 @@ class CMB(DiffuseComponent):
     """
 
     label = SkyComponentLabel.CMB
+    freq_range = (0 * Unit("Hz"), 1 * Unit("THz"))
 
     def get_freq_scaling(self, *_) -> Quantity:
         """See base class.
 
-        NOTE: The CMB amplitude is stored in units of uK_CMB where it is
-        constant over the sky.
+        NOTE: The CMB amplitude maps are stored in units of uK_CMB for which
+        they are constant over frequencies.
         """
 
         return Quantity(1)
