@@ -137,7 +137,7 @@ if False:
 #ratio_y = l
 #ratio = width/7*0.04
 
-if True:
+if False: #simplest
     plot(path+dust, width="m", sig="Q",comp="dust",norm="log")
     plt.show()
     #plt.savefig("testm.png", dpi=600, pad_inches = 0, bbox_inches="tight")
@@ -250,6 +250,79 @@ if False:
         plt.savefig(f"/Users/svalheim/work/thesis/figures/gifs/smallgif_{i+1}.png", bbox_inches='tight',  pad_inches=0.02, transparent=True, dpi=300)
         plt.show()
 
+# %%
+import numpy as np
+import matplotlib.pyplot as plt
+import healpy as hp
+from cosmoglobe import plot
+
+import h5py
+
+from sys import exit
+
+
+def real_2_alm(rlm, lmax, mmax):
+    cx_alm = np.zeros(mmax * (2 * lmax + 1 - mmax) // 2 + lmax + 1, dtype="complex")
+
+    for l in range(0, lmax):
+        for m in range(0, mmax):
+            if m > l:
+                continue
+            healpixI = hp.sphtfunc.Alm.getidx(lmax, l, m)
+            outI = getOutidx(l, m)
+            outJ = getOutidx(l, -1 * m)
+            if m == 0:
+                cx_alm[healpixI] = rlm[outI]
+            else:
+                cx_alm[healpixI] = (rlm[outI] + 1j * rlm[outJ]) / 2 ** 0.5
+
+    return cx_alm
+
+
+def getOutidx(l, m):
+    return l ** 2 + l + m
+
+
+def main(
+    rot=0, nside_planck=4096,
+):
+    # According to the BP overview paper, the Planck beams are normalized such that
+    # their integral combined is equal to unity.
+    path="./"
+    path="/Users/svalheim/work/workdir-thesis/beams/"
+    data = h5py.File(path+"LFI_instrument_v6.h5", "r")
+
+    blm = data["27S/beam/T"][...]
+    blmax = data["27S/beamlmax"][...]
+    bmmax = data["27S/beammmax"][...]
+
+    slm = data["27S/sl/T"][...]
+    slmax = data["27S/sllmax"][...]
+    smmax = data["27S/slmmax"][...]
+
+    cx_alm = real_2_alm(slm, slmax[0], smmax[0])
+    # s_lp = hp.alm2cl(cx_alm, lmax=slmax[0], mmax=smmax[0]) ** 0.5 * (4 * np.pi) ** 0.5
+    m = hp.alm2map(cx_alm, nside_planck, lmax=slmax[0], mmax=smmax[0])
+    m[m <= 0] = min(abs(m))
+
+    arcmin2rad=0.000290888
+    cx_alm = real_2_alm(blm, blmax[0], bmmax[0])
+    m1 = hp.alm2map(cx_alm, nside_planck, lmax=blmax[0], mmax=bmmax[0])
+    m1[m1 <=2e-2] = min(abs(m1))
+  
+    #hp.mollview(m,  rot=(0, 90, 0), norm="log", min=1e-5, max=5e-2, cmap="afmhot", title="27S Beam sidelobes")
+    #hp.mollview(m1, rot=(0, 90, 0), min=0,  cmap="afmhot", title="main beam")
+    #hp.gnomview(m1, rot=(0, 90, 0), reso=0.75, min=0, max=1, cmap="afmhot", title="Main beam")
+    #hp.mollview(m + m1, rot=(0, 90, 0), min=1e-5, max=1000, norm="log", cmap="afmhot", title="combined beams")
+    #plot(np.log10(m + m1), rot=(0, 90, 0), min=-5, max=3, cmap="afmhot",)
+    plot(m + m1, rot=(0, 90, 0), min=1e-5, max=5e-2,norm="log", cmap="afmhot",width="l")
+
+    #print(m.shape, m1.shape)
+    plt.show()
+
+main(nside_planck=2048)
+
+
 # %%
 
 
